﻿using System;
using System.Configuration;
using Alachisoft.NCache.Runtime;
using Alachisoft.NCache.Runtime.Dependencies;
using Alachisoft.NCache.Web.Caching;

// ===============================================================================
// Alachisoft (R) NCache Sample Code.
// NCache Database Dependency sample
// ===============================================================================
// Copyright © Alachisoft.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
// ===============================================================================

namespace Dependency
{
	public class DBDependency
	{
		public static void RunDBDependencyDemo()
		{
			try
			{
				//Initialize cache

				Cache cache;
				cache = NCache.InitializeCache("mypartitionedcache");
				cache.Clear();

				//Scripts are provided to enable 
			    //DBNotifications to NCache

				//Notification based DBDependency
				//JDBC connectionString                         

                string connectionString = ConfigurationManager.AppSettings["ConnectionString"];

				for (int i = 0; i < 10; i++)
				{
					//Cache key for product id 10 will be "10:dbo.Products"
					CacheDependency dependency = DBDependencyFactory.CreateOleDbCacheDependency(connectionString, Convert.ToString(i) + ":oldRow.Products");
					cache.Insert(i + ":oldRow.Products", i, dependency, Cache.NoAbsoluteExpiration, Cache.NoSlidingExpiration, CacheItemPriority.Default);
				}

				Console.WriteLine("Update product with id 6 in database and press enter...");
				Console.Read();

				//Demo is specified for cache_key 6:oldRow.Products 
				if (cache.Contains("6:oldRow.Products"))
				{
					Console.WriteLine("Oracle dependency did not work as expected. " + "Check your connection string and sql command syntax.");
				}
				else
				{
					Console.WriteLine("6:oldRow.Products removed due to oracle dependency.");
				}

				//Must dispose cache
				cache.Dispose();


			}
			catch (Exception ex)
			{
				Console.Write(ex.Message);
			}
		}
	}

}